/*********************************************************************************
 *
 *  Test code for the CFA-10004 carrier board with the CFAG4265A 1" LCD
 *
 *  cfa-10003.h
 *
 *
 *********************************************************************************/

#ifndef __CFA_10003_H__
#define __CFA_10003_H__



/* Port and bit definitions
 */
#define LCD_A0      PA7     /* 0 = LCD CMD, 1 = LCD DATA */
#define DAC_CS      PA5     /* Active LOW, DAC CS */
#define LCD5_CS     PA4     /* Active LOW, LCD CS */
#define LCD4_CS     PA3     /* Active LOW */
#define LCD3_CS     PA2     /* Active LOW */
#define LCD2_CS     PA1     /* Active LOW */
#define LCD1_CS     PA0     /* Active LOW */

#define LCD1_PWM    PB7     /* LCD1 Backlight Control */
#define LCD_RST     PB6     /* All LCD Reset, Active LOW */
#define LCD2_PWM    PB5     /* LCD2 Backlight Control */
#define LCD3_PWM    PB4     /* LCD3 Backlight Control */
#define MISO        PINB3   /* SPI Interface */
#define MOSI        PB2     /* SPI Interface */
#define SCK         PB1     /* SPI Interface */
#define SD_CS       PB0     /* microSD CS, Active LOW */

#define SW4         PIND7   /* Active LOW */
#define SW3         PIND6   /* Active LOW */
#define SW2         PIND5   /* Active LOW */
#define SW1         PIND4   /* Active LOW */
#define LED2        PD2     /* Active HIGH */
#define LED1        PD1     /* Active HIGH */

#define LCD4_PWM    PE3     /* LCD4 Backlight Control */

#define LCD_CTRL    PORTA



/* LTC2630-8 DAC Commands
 */
typedef enum {
     DAC_REG_WRITE        = 0b00000000,
     DAC_REG_UPDATE       = 0b00010000,
     DAC_REG_WRITE_UPDATE = 0b00110000,
     DAC_POWER_DOWN       = 0b01000000,
     DAC_INTERNAL_REF     = 0b01100000,
     DAC_VCC_REF          = 0b01110000,
} dac_cmd_t;


#define NULL_DATA   0

/* Backlight full on at DAC output = 1.5V
 * Backlight off at DAC output < 50mV
 */
#define BACKLIGHT_FULL_ON   232
#define BACKLIGHT_FULL_OFF  0

/* ST7565P LCD Controller Definitions
 */
#define LCD_BIAS_1_7    1
#define LCD_BIAS_1_9    0
#define NORMAL  0
#define REVERSE 1

#define LCD_RATIO_3_0   0b000
#define LCD_RATIO_3_5   0b001
#define LCD_RATIO_4_0   0b010
#define LCD_RATIO_4_5   0b011
#define LCD_RATIO_5_0   0b100
#define LCD_RATIO_5_5   0b101
#define LCD_RATIO_6_0   0b110
#define LCD_RATIO_6_5   0b111

#define LCD_BOOSTER_2X  0
#define LCD_BOOSTER_3X  0
#define LCD_BOOSTER_4X  0
#define LCD_BOOSTER_5X  0b01
#define LCD_BOOSTER_6X  0b11

#define BOOST_ON    1
#define BOOST_OFF   0
#define VR_ON       1
#define VR_OFF      0
#define VF_ON       1
#define VF_OFF      0

#define LOW_CONTRAST    15
#define DEF_CONTRAST    32
#define HIGH_CONTRAST   52

/* Function prototypes
 */
void dac_init(void);
void dac_cmd_send(dac_cmd_t cmd, uint8_t data);
void spi_init(void);
void spi_master_send_byte(uint8_t data);
void gpio_init(void);
void delay_100ms(uint8_t tenth_seconds);

void lcd_init(uint8_t disp);
void lcd_data_send(uint8_t disp, uint8_t data);
void lcd_cmd_send(uint8_t disp, uint8_t data);
void lcd_reset(void);
void lcd_clear(uint8_t disp);
void lcd_fill(uint8_t disp, uint8_t data, uint16_t delay_ms_col, uint16_t delay_ms_page);

void lcd_backlight_set(uint8_t brightness);
void lcd_init_backlight_pwm_1(uint8_t brightness);
void lcd_set_backlight_1(uint8_t brightness);
void lcd_init_backlight_pwm_2(uint8_t brightness);
void lcd_set_backlight_2(uint8_t brightness);
void lcd_init_backlight_pwm_3(uint8_t brightness);
void lcd_set_backlight_3(uint8_t brightness);
void lcd_init_backlight_pwm_4(uint8_t brightness);
void lcd_set_backlight_4(uint8_t brightness);

void lcd_display_on(uint8_t disp);
void lcd_display_off(uint8_t disp);
void lcd_start_line_set(uint8_t disp, uint8_t line);
void lcd_page_address_set(uint8_t disp, uint8_t page);
void lcd_column_address_set(uint8_t disp, uint8_t column);
void lcd_adc_select(uint8_t disp, uint8_t direction);
void lcd_display_reverse(uint8_t disp, uint8_t reverse);
void lcd_all_points(uint8_t disp, uint8_t on);
void lcd_bias_set(uint8_t disp, uint8_t bias);
void lcd_cmd_reset(uint8_t disp);
void lcd_common_output_mode_select(uint8_t disp, uint8_t reverse);
void lcd_power_controller_set(uint8_t disp, uint8_t boost, uint8_t vreg, uint8_t vfollower);
void lcd_electronic_volume_set(uint8_t disp, uint8_t contrast);
void lcd_vo_regulator_resistor_set(uint8_t disp, uint8_t ratio);
void lcd_booster_ratio_set(uint8_t disp, uint8_t ratio);


#endif
